aboutsummaryrefslogtreecommitdiff
path: root/source/feedgetter.py
diff options
context:
space:
mode:
authorcedricbonhomme <devnull@localhost>2012-04-22 23:05:30 +0200
committercedricbonhomme <devnull@localhost>2012-04-22 23:05:30 +0200
commit0fc25218ad337c208024b325ec4c0c5656ee893e (patch)
treedd004aeb14384bf20a01dce9d85e81f7248347c7 /source/feedgetter.py
parentRemoved set_max_articles() function.~ (diff)
downloadnewspipe-0fc25218ad337c208024b325ec4c0c5656ee893e.tar.gz
newspipe-0fc25218ad337c208024b325ec4c0c5656ee893e.tar.bz2
newspipe-0fc25218ad337c208024b325ec4c0c5656ee893e.zip
Added conf.py which is responsible of the load of the configuration.
Diffstat (limited to 'source/feedgetter.py')
-rwxr-xr-xsource/feedgetter.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/source/feedgetter.py b/source/feedgetter.py
index f713f672..aa25f2a3 100755
--- a/source/feedgetter.py
+++ b/source/feedgetter.py
@@ -32,6 +32,7 @@ from BeautifulSoup import BeautifulSoup
from datetime import datetime
+import conf
import utils
import mongodb
@@ -145,7 +146,7 @@ class FeedGetter(object):
self.articles.add_articles(articles, feed_id)
# send new articles by e-mail if desired.
#threading.Thread(None, utils.send_mail, None, (utils.mail_from, utils.mail_to, \
#a_feed.feed.title.encode('utf-8'), \
#article_title, description) \
#).start()
@@ -145,7 +146,7 @@ class FeedGetter(object):
self.articles.add_articles(articles, feed_id)
# send new articles by e-mail if desired.
- #threading.Thread(None, utils.send_mail, None, (utils.mail_from, utils.mail_to, \
+ #threading.Thread(None, utils.send_mail, None, (conf.mail_from, conf.mail_to, \
#a_feed.feed.title.encode('utf-8'), \
#article_title, description) \
bgstack15